@@ -1,5 +1,5 @@
 /* This file is part of the KDE libraries
-   Copyright (C) 2012 Dominik Haumann <dhaumann kde org>
+   Copyright (C) 2012-2018 Dominik Haumann <dhaumann@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,7 +20,7 @@
 #ifndef KATE_BUG_286887_TEST_H
 #define KATE_BUG_286887_TEST_H
 
-#include <QtCore/QObject>
+#include <QObject>
 
 class BugTest : public QObject
 {
