@@ -1,37 +1,36 @@
-/*  This file is part of the Kate project.
- *
- *  Copyright (C) 2010 Christoph Cullmann <cullmann@kde.org>
- *
- *  Based on code of the SmartCursor/Range by:
- *  Copyright (C) 2003-2005 Hamish Rodda <rodda@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2010 Christoph Cullmann <cullmann@kde.org>
+
+    Based on code of the SmartCursor/Range by:
+    Copyright (C) 2003-2005 Hamish Rodda <rodda@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #ifndef KATE_TEXTCURSOR_H
 #define KATE_TEXTCURSOR_H
 
 #include <ktexteditor/movingcursor.h>
 
-#include <ktexteditor_export.h>
 #include "katetextblock.h"
+#include <ktexteditor_export.h>
 
 namespace Kate
 {
-
 class TextBuffer;
 class TextBlock;
 class TextRange;
@@ -71,13 +70,13 @@ public:
     /**
      * Destruct the text cursor
      */
-    ~TextCursor() Q_DECL_OVERRIDE;
+    ~TextCursor() override;
 
     /**
      * Set insert behavior.
      * @param insertBehavior new insert behavior
      */
-    void setInsertBehavior(InsertBehavior insertBehavior) Q_DECL_OVERRIDE
+    void setInsertBehavior(InsertBehavior insertBehavior) override
     {
         m_moveOnInsert = insertBehavior == MoveOnInsert;
     }
@@ -86,7 +85,7 @@ public:
      * Get current insert behavior.
      * @return current insert behavior
      */
-    InsertBehavior insertBehavior() const Q_DECL_OVERRIDE
+    InsertBehavior insertBehavior() const override
     {
         return m_moveOnInsert ? MoveOnInsert : StayOnInsert;
     }
@@ -95,7 +94,7 @@ public:
      * Gets the document to which this cursor is bound.
      * \return a pointer to the document
      */
-    KTextEditor::Document *document() const Q_DECL_OVERRIDE;
+    KTextEditor::Document *document() const override;
 
     /**
      * Fast way to set the current cursor position to \e position.
@@ -109,7 +108,7 @@ public:
      *
      * \param position new cursor position
      */
-    void setPosition(const KTextEditor::Cursor &position) Q_DECL_OVERRIDE;
+    void setPosition(const KTextEditor::Cursor &position) override;
 
     /**
      * \overload
@@ -128,7 +127,7 @@ public:
      * Retrieve the line on which this cursor is situated.
      * \return line number, where 0 is the first line.
      */
-    int line() const Q_DECL_OVERRIDE;
+    int line() const override;
 
     /**
      * Non-virtual version of line(), which is faster.
@@ -150,7 +149,7 @@ public:
      * Retrieve the column on which this cursor is situated.
      * \return column number, where 0 is the first column.
      */
-    int column() const Q_DECL_OVERRIDE
+    int column() const override
     {
         return m_column;
     }
@@ -168,7 +167,7 @@ public:
      * Get range this cursor belongs to, if any
      * @return range this pointer is part of, else 0
      */
-    KTextEditor::MovingRange *range() const Q_DECL_OVERRIDE;
+    KTextEditor::MovingRange *range() const override;
 
     /**
      * Get range this cursor belongs to, if any
@@ -196,7 +195,8 @@ public:
     {
         if (m_block) {
             return m_line;
-        } return -1;
+        }
+        return -1;
     }
 
 private:
@@ -208,7 +208,7 @@ private:
     /**
      * no assignment operator, no copying around.
      */
-    TextCursor &operator= (const TextCursor &);
+    TextCursor &operator=(const TextCursor &);
 
     /**
      * Set the current cursor position to \e position.
