@@ -1,43 +1,44 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
- *  Copyright (C) 2009 Erlend Hamberg <ehamberg@gmail.com>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef __KATE_GLOBAL_H__
-#define __KATE_GLOBAL_H__
+    Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
+    Copyright (C) 2009 Erlend Hamberg <ehamberg@gmail.com>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
+
+#ifndef KATE_GLOBAL_H
+#define KATE_GLOBAL_H
 
-#include <ktexteditor_export.h>
 #include "katescript.h"
+#include "variable.h"
+#include <ktexteditor_export.h>
 
-#include <ktexteditor/editor.h>
 #include "ktexteditor/view.h"
+#include <ktexteditor/editor.h>
 
 #include <KAboutData>
 #include <KSharedConfig>
 
 #include <KTextEditor/Application>
-#include <KTextEditor/MainWindow>
 #include <KTextEditor/Command>
+#include <KTextEditor/MainWindow>
 
 #include <QList>
-#include <QPointer>
 #include <QMap>
+#include <QPointer>
 #include <QScopedPointer>
 
 class QStringListModel;
@@ -49,8 +50,14 @@ class KateGlobalConfig;
 class KateDocumentConfig;
 class KateViewConfig;
 class KateRendererConfig;
-namespace KTextEditor { class DocumentPrivate; }
-namespace KTextEditor { class ViewPrivate; }
+namespace KTextEditor
+{
+class DocumentPrivate;
+}
+namespace KTextEditor
+{
+class ViewPrivate;
+}
 class KateScriptManager;
 class KDirWatch;
 class KateHlManager;
@@ -59,10 +66,10 @@ class KateWordCompletionModel;
 class KateAbstractInputModeFactory;
 class KateKeywordCompletionModel;
 class KateDefaultColors;
+class KateVariableExpansionManager;
 
 namespace KTextEditor
 {
-
 /**
  * KTextEditor::EditorPrivate
  * One instance of this class is hold alive during
@@ -98,7 +105,7 @@ private:
      * Default constructor, private, as singleton
      * @param staticInstance pointer to fill with content of this
      */
-    EditorPrivate(QPointer<KTextEditor::EditorPrivate> &staticInstance);
+    explicit EditorPrivate(QPointer<KTextEditor::EditorPrivate> &staticInstance);
 
 public:
     /**
@@ -157,14 +164,14 @@ public:
     }
 
     /**
-    * Configuration management
-    */
+     * Configuration management
+     */
 public:
     /**
      * Shows a config dialog for the part, changes will be applied
      * to the editor, but not saved anywhere automagically, call
      * writeConfig to save them
-    */
+     */
     void configDialog(QWidget *parent) override;
 
     /**
@@ -240,13 +247,7 @@ public:
      * The global configuration of katepart, e.g. katepartrc
      * @return global shared access to katepartrc config
      */
-    static KSharedConfigPtr config()
-    {
-        // use dummy config for unit tests!
-        return KTextEditor::EditorPrivate::unitTestMode()
-            ? KSharedConfig::openConfig(QStringLiteral("katepartrc-unittest"), KConfig::SimpleConfig, QStandardPaths::TempLocation)
-            : KSharedConfig::openConfig(QStringLiteral("katepartrc"));
-    }
+    static KSharedConfigPtr config();
 
     /**
      * global mode manager
@@ -342,7 +343,8 @@ public:
      * Global instance of the language-aware keyword completion model
      * @return global instance of the keyword completion model
      */
-    KateKeywordCompletionModel *keywordCompletionModel () {
+    KateKeywordCompletionModel *keywordCompletionModel()
+    {
         return m_keywordCompletionModel;
     }
 
@@ -427,6 +429,11 @@ public:
      */
     void saveSearchReplaceHistoryModels();
 
+    /**
+     * Returns the variable expansion manager.
+     */
+    KateVariableExpansionManager *variableExpansionManager();
+
 Q_SIGNALS:
     /**
      * Emitted if the history of clipboard changes via copyToClipboard
@@ -510,6 +517,11 @@ private:
      */
     KateCmd *m_cmdManager;
 
+    /**
+     * variable expansion manager
+     */
+    KateVariableExpansionManager *m_variableExpansionManager;
+
     /**
      * spell check manager
      */
@@ -565,4 +577,3 @@ private:
 }
 
 #endif
-
