@@ -1,45 +1,50 @@
-/* This file is part of the KDE and the Kate project
- *
- *   Copyright (C) 2013 Dominik Haumann <dhaumann@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2013 Dominik Haumann <dhaumann@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #include "katestatusbar.h"
 
-#include "katemodemenulist.h"
+#include "kateabstractinputmode.h"
+#include "kateconfig.h"
+#include "katedocument.h"
 #include "kateglobal.h"
 #include "katemodemanager.h"
-#include "katedocument.h"
-#include "kateconfig.h"
-#include "kateabstractinputmode.h"
+#include "katemodemenulist.h"
 #include "wordcounter.h"
 
-#include <KActionCollection>
-#include <KLocalizedString>
-#include <KIconUtils>
 #include <KAcceleratorManager>
+#include <KActionCollection>
+#include <KIconUtils>
+#include <KLocalizedString>
 #include <Sonnet/Speller>
 
 #include <QHBoxLayout>
 #include <QInputDialog>
 
-//BEGIN menu
-KateStatusBarOpenUpMenu::KateStatusBarOpenUpMenu(QWidget *parent) : QMenu(parent) {}
-KateStatusBarOpenUpMenu::~KateStatusBarOpenUpMenu() {}
+// BEGIN menu
+KateStatusBarOpenUpMenu::KateStatusBarOpenUpMenu(QWidget *parent)
+    : QMenu(parent)
+{
+}
+KateStatusBarOpenUpMenu::~KateStatusBarOpenUpMenu()
+{
+}
 
 void KateStatusBarOpenUpMenu::setVisible(bool visibility)
 {
@@ -47,15 +52,16 @@ void KateStatusBarOpenUpMenu::setVisible(bool visibility)
         QRect geo = geometry();
         QPoint pos = parentWidget()->mapToGlobal(QPoint(0, 0));
         geo.moveTopLeft(QPoint(pos.x(), pos.y() - geo.height()));
-        if (geo.top() < 0) geo.moveTop(0);
+        if (geo.top() < 0)
+            geo.moveTop(0);
         setGeometry(geo);
     }
 
     QMenu::setVisible(visibility);
 }
-//END menu
+// END menu
 
-//BEGIN StatusBarButton
+// BEGIN StatusBarButton
 StatusBarButton::StatusBarButton(KateStatusBar *parent, const QString &text /*= QString()*/)
     : QPushButton(text, parent)
 {
@@ -67,7 +73,7 @@ StatusBarButton::StatusBarButton(KateStatusBar *parent, const QString &text /*=
 StatusBarButton::~StatusBarButton()
 {
 }
-//END StatusBarButton
+// END StatusBarButton
 
 KateStatusBar::KateStatusBar(KTextEditor::ViewPrivate *view)
     : KateViewBarWidget(false)
@@ -196,11 +202,10 @@ KateStatusBar::KateStatusBar(KTextEditor::ViewPrivate *view)
     modeMenuList->updateMenu(m_view->doc());
     /**
      * add mode button which allows user to switch mode of document
-     * this will reuse the mode action menu of the view
      */
     m_mode = new StatusBarButton(this);
     topLayout->addWidget(m_mode);
-    modeMenuList->setButton(m_mode, false, KateModeMenuList::Inverse);
+    modeMenuList->setButton(m_mode, KateModeMenuList::AlignHInverse, KateModeMenuList::AlignTop, KateModeMenuList::AutoUpdateTextButton(false));
     m_mode->setMenu(modeMenuList);
     m_mode->setWhatsThis(i18n("Syntax highlighting"));
 
@@ -251,7 +256,6 @@ void KateStatusBar::contextMenuEvent(QContextMenuEvent *event)
     showWords->setCheckable(true);
     showWords->setChecked(KateViewConfig::global()->showWordCount());
     menu.exec(event->globalPos());
-
 }
 
 void KateStatusBar::toggleShowLines(bool checked)
@@ -304,17 +308,12 @@ void KateStatusBar::cursorPositionChanged()
     // Update line/column label
     QString text;
     if (KateViewConfig::global()->showLineCount()) {
-        text = i18n("Line %1 of %2, Column %3", QLocale().toString(position.line() + 1)
-                                              , QLocale().toString(m_view->doc()->lines())
-                                              , QLocale().toString(position.column() + 1)
-                   );
+        text = i18n("Line %1 of %2, Column %3", QLocale().toString(position.line() + 1), QLocale().toString(m_view->doc()->lines()), QLocale().toString(position.column() + 1));
     } else {
-        text = i18n("Line %1, Column %2", QLocale().toString(position.line() + 1)
-                                        , QLocale().toString(position.column() + 1)
-                   );
+        text = i18n("Line %1, Column %2", QLocale().toString(position.line() + 1), QLocale().toString(position.column() + 1));
     }
     if (m_wordCounter) {
-        text.append(QStringLiteral(", ") + m_wordCount);
+        text.append(QLatin1String(", ") + m_wordCount);
     }
     m_cursorPosition->setText(text);
 }
@@ -325,7 +324,7 @@ void KateStatusBar::updateDictionary()
     // Check if at the current cursor position is a special dictionary in use
     KTextEditor::Cursor position(m_view->cursorPositionVirtual());
     const QList<QPair<KTextEditor::MovingRange *, QString>> dictRanges = m_view->doc()->dictionaryRanges();
-    for (auto rangeDictPair : dictRanges) {
+    for (const auto &rangeDictPair : dictRanges) {
         const KTextEditor::MovingRange *range = rangeDictPair.first;
         if (range->contains(position) || range->end() == position) {
             newDict = rangeDictPair.second;
@@ -400,8 +399,7 @@ void KateStatusBar::modifiedChanged()
 
     case 0x3:
     case 0x7:
-        m_modified->setIcon(QIcon(KIconUtils::addOverlay(QIcon::fromTheme(QStringLiteral("document-save")),
-                                       QIcon(QStringLiteral("emblem-important")), Qt::TopLeftCorner)));
+        m_modified->setIcon(QIcon(KIconUtils::addOverlay(QIcon::fromTheme(QStringLiteral("document-save")), QIcon(QStringLiteral("emblem-important")), Qt::TopLeftCorner)));
         m_modified->setWhatsThis(QString());
         break;
 
@@ -473,10 +471,11 @@ void KateStatusBar::updateGroup(QActionGroup *group, int w)
 {
     QAction *m1 = nullptr;
     bool found = false;
-    //linear search should be fast enough here, no additional hash
+    // linear search should be fast enough here, no additional hash
     for (QAction *action : group->actions()) {
         int val = action->data().toInt();
-        if (val == -1) m1 = action;
+        if (val == -1)
+            m1 = action;
         if (val == w) {
             found = true;
             action->setChecked(true);
@@ -497,7 +496,8 @@ void KateStatusBar::slotTabGroup(QAction *a)
     KateDocumentConfig *config = ((KTextEditor::DocumentPrivate *)m_view->document())->config();
     if (val == -1) {
         val = QInputDialog::getInt(this, i18n("Tab Width"), i18n("Please specify the wanted tab width:"), config->tabWidth(), 1, 16, 1, &ok);
-        if (!ok) val = config->tabWidth();
+        if (!ok)
+            val = config->tabWidth();
     }
     config->setTabWidth(val);
 }
@@ -509,11 +509,13 @@ void KateStatusBar::slotIndentGroup(QAction *a)
     KateDocumentConfig *config = ((KTextEditor::DocumentPrivate *)m_view->document())->config();
     if (val == -1) {
         val = QInputDialog::getInt(this, i18n("Indentation Width"), i18n("Please specify the wanted indentation width:"), config->indentationWidth(), 1, 16, 1, &ok);
-        if (!ok) val = config->indentationWidth();
+        if (!ok)
+            val = config->indentationWidth();
     }
     config->configStart();
     config->setIndentationWidth(val);
-    if (m_hardAction->isChecked()) config->setTabWidth(val);
+    if (m_hardAction->isChecked())
+        config->setTabWidth(val);
     config->configEnd();
 }
 
@@ -559,11 +561,7 @@ void KateStatusBar::toggleWordCount(bool on)
 void KateStatusBar::wordCountChanged(int wordsInDocument, int wordsInSelection, int charsInDocument, int charsInSelection)
 {
     if (m_wordCounter) {
-        m_wordCount = i18nc(
-            "%1 and %3 are the selected words/chars count, %2 and %4 are the total words/chars count.",
-            "Words %1/%2, Chars %3/%4",
-            wordsInSelection, wordsInDocument, charsInSelection, charsInDocument
-        );
+        m_wordCount = i18nc("%1 and %3 are the selected words/chars count, %2 and %4 are the total words/chars count.", "Words %1/%2, Chars %3/%4", wordsInSelection, wordsInDocument, charsInSelection, charsInDocument);
     } else {
         m_wordCount.clear();
     }
